require 'xcodeproj'

require 'optparse'


options = {}
OptionParser.new do |parser|
  parser.banner = "firebase_crashlytics upload debug symbols script"

  parser.on("-x", "--xcodeProjFilePath=XCODEFILE", String, "Xcode project path") do |xcodeProjFilePath|
    options[:xcodeProjFilePath] = xcodeProjFilePath
  end

  parser.on("-a", "--appId=APPID", String, "Google App ID") do |appId|
    options[:appId] = appId
  end

  parser.on("-s", "--scheme=SCHEME", String, "Scheme") do |scheme|
    options[:scheme] = scheme
  end

  parser.on("-n", "--scriptName=SCRIPTNAME", String, "Script name") do |scriptName|
    options[:scriptName] = scriptName
  end

end.parse!


schemes = options[:scheme]
bashScript = <<~HEREDOC
#!/bin/bash

# Run upload symbol script for appropriate scheme. Each scheme has multiple configurations (i.e. Debug-development, Debug-staging, etc).
# This is why we use *"scheme"*
if [[ "\${CONFIGURATION}" == *"#{schemes}"* ]];
  then
      echo "Running #{options[:scriptName]}"
      $PODS_ROOT/FirebaseCrashlytics/upload-symbols --build-phase --validate -ai "#{options[:appId]}"
      $PODS_ROOT/FirebaseCrashlytics/upload-symbols --build-phase -ai "#{options[:appId]}"
  fi     
HEREDOC

project = Xcodeproj::Project.open(options[:xcodeProjFilePath])

for target in project.targets 
  phase = target.shell_script_build_phases().find {|item| item.name == options[:scriptName]}
  if (phase.nil?)
      phase = target.new_shell_script_build_phase(options[:scriptName])
      phase.shell_script = bashScript
      phase.input_paths = ["\"${DWARF_DSYM_FOLDER_PATH}/${DWARF_DSYM_FILE_NAME}/Contents/Resources/DWARF/${TARGET_NAME}\"", "\"$(SRCROOT)/$(BUILT_PRODUCTS_DIR)/$(INFOPLIST_PATH)\""]
      project.save() 
  else
      $stdout.write "firebase_crashlytics upload debug symbols script script already exists for #{options[:scheme]}, skipping..."
      exit(0)
  end
end
