import 'dart:io';

String addCrashlyticsDebugSymbolScriptToScheme(
  String xcodeProjFilePath,
  String appId,
  String scheme,
  String runScriptName,
) {
  return '''
require 'xcodeproj'
bashScript = %q(
#!/bin/bash

# Run upload symbol script for appropriate scheme. Each scheme has multiple configurations (i.e. Debug-development, Debug-staging, etc).
# This is why we use *"scheme"*
if [[ "\${CONFIGURATION}" == *"$scheme"* ]];
then
    echo "Running $runScriptName"
    \$PODS_ROOT/FirebaseCrashlytics/upload-symbols --build-phase --validate -ai '$appId'
    \$PODS_ROOT/FirebaseCrashlytics/upload-symbols --build-phase -ai '$appId'
fi     
)

input_paths = ["\\"\${DWARF_DSYM_FOLDER_PATH}/\${DWARF_DSYM_FILE_NAME}/Contents/Resources/DWARF/\${TARGET_NAME}\\"", "\\"\$(SRCROOT)/\$(BUILT_PRODUCTS_DIR)/\$(INFOPLIST_PATH)\\""]

project = Xcodeproj::Project.open('$xcodeProjFilePath')

for target in project.targets 
  phase = target.shell_script_build_phases().find {|item| item.name == '$runScriptName'}
  if (phase.nil?)
      phase = target.new_shell_script_build_phase('$runScriptName')
      phase.shell_script = bashScript
      phase.input_paths = input_paths
      project.save() 
  else
      \$stdout.write "firebase_crashlytics upload debug symbols script script already exists for $scheme, skipping..."
      exit(0)
  end
end
''';
}

void main(List<String> args) async {
  final adUploadSymbolsScript = addCrashlyticsDebugSymbolScriptToScheme(
    '/Users/russellwheatley/projects/devTests/service_testing/ios/Runner.xcodeproj',
    '1:361461320736:ios:6ecd45b6d0d3126f6f8045',
    'development',
    'firebase_crashlytics upload debug symbols script for development scheme',
  );

  final resultUploadScript = await Process.run('ruby', [
    '-e',
    adUploadSymbolsScript,
  ]);

  if (resultUploadScript.exitCode != 0) {
    print('Error uploading debug symbols');
    print(resultUploadScript.stderr);
  } else {
    print('Debug symbols uploaded');
    print(resultUploadScript.stdout);
  }
}
